@@ -37,12 +37,14 @@ sub dump_form
 print &ui_table_row(&hlink($text{'dump_dest'}, "dest"),
    &ui_radio("mode", $_[0]->{'host'} ? 1 : 0,
 	[ [ 0, $text{'dump_file'}." ".
-	       &ui_textbox("file", $_[0]->{'file'}, 50).
+	       &ui_textbox("file", $_[0]->{'file'}, 50, undef, undef,
+	    $config{'date_subs'} ?
+	        'placeholder="/backups/filename-%y-%m-%d-%H-%M-%S.tar.gz"' : undef).
 	       " ".&file_chooser_button("file")."<br>" ],
 	  [ 1, &text('dump_host',
-		     &ui_textbox("host", $_[0]->{'host'}, 15),
-		     &ui_textbox("huser", $_[0]->{'huser'}, 8),
-		     &ui_textbox("hfile", $_[0]->{'hfile'}, 20)) ] ]), 3);
+		     &ui_textbox("host", $_[0]->{'host'}, 20),
+		     &ui_textbox("huser", $_[0]->{'huser'}, 15),
+		     &ui_textbox("hfile", $_[0]->{'hfile'}, 40)) ] ]), 3);
 
 if ($_[0]->{'fs'} ne 'xfs') {
 	# Display remote target options
@@ -77,7 +79,8 @@ if ($_[0]->{'fs'} eq 'tar') {
 			    &ui_select("gzip", int($_[0]->{'gzip'}),
 				[ [ 0, $text{'no'} ],
 				  [ 1, $text{'dump_gzip1'} ],
-				  [ 2, $text{'dump_gzip2'} ] ]), 1, $tds);
+				  [ 2, $text{'dump_gzip2'} ],
+				  [ 3, $text{'dump_gzip3'} ] ]), 1, $tds);
 
 	print &ui_table_row(&hlink($text{'dump_multi'},"multi"),
 			    &ui_yesno_radio("multi", int($_[0]->{'multi'})),
@@ -104,6 +107,11 @@ if ($_[0]->{'fs'} eq 'tar') {
 			    &ui_yesno_radio("ignoreread",
 					    int($_[0]->{'ignoreread'})),
 			    1, $tds);
+
+	print &ui_table_row(&hlink($text{'dump_ignorechanged'},"ignorechanged"),
+			    &ui_yesno_radio("ignorechanged",
+					    int($_[0]->{'ignorechanged'})),
+			    1, $tds);
 	}
 elsif ($_[0]->{'fs'} eq 'xfs') {
 	# Display xfs dump options
@@ -247,6 +255,7 @@ if ($_[0]->{'fs'} eq 'tar') {
 		}
 	$_[0]->{'update'} = $in{'update'};
 	$_[0]->{'ignoreread'} = $in{'ignoreread'};
+	$_[0]->{'ignorechanged'} = $in{'ignorechanged'};
 	if ($in{'gzip'} && $in{'update'}) {
 		&error($text{'dump_egzip3'});
 		}
@@ -347,6 +356,7 @@ local $tapecmd = $_[0]->{'multi'} && $_[0]->{'fs'} eq 'tar' ? $multi_cmd :
 		 $_[3] && !$config{'nonewtape'} ? $newtape_cmd : $notape_cmd;
 local @dirs = $_[0]->{'tabs'} ? split(/\t+/, $_[0]->{'dir'})
 			      : split(/\s+/, $_[0]->{'dir'});
+@dirs = map { &date_subs($_) } @dirs;
 if ($_[0]->{'fs'} eq 'tar') {
 	# tar format backup
 	$cmd = "tar ".($_[0]->{'update'} ? "-u" : "-c")." ".$flag;
@@ -354,6 +364,7 @@ if ($_[0]->{'fs'} eq 'tar') {
 	$cmd .= " -L $_[0]->{'blocks'}" if ($_[0]->{'blocks'});
 	$cmd .= " -z" if ($_[0]->{'gzip'} == 1);
 	$cmd .= " --bzip" if ($_[0]->{'gzip'} == 2);
+	$cmd .= " -J" if ($_[0]->{'gzip'} == 3);
 	$cmd .= " -M" if ($_[0]->{'multi'});
 	$cmd .= " -h" if ($_[0]->{'links'});
 	$cmd .= " --one-file-system" if ($_[0]->{'xdev'});
@@ -364,6 +375,7 @@ if ($_[0]->{'fs'} eq 'tar') {
 	$cmd .= " --rmt-command=".quotemeta($_[0]->{'rmt'})
 		if ($_[0]->{'rmt'});
 	$cmd .= " --ignore-failed-read" if ($_[0]->{'ignoreread'});
+	$cmd .= " --warning=no-file-changed" if ($_[0]->{'ignorechanged'});
 	if ($_[0]->{'exclude'}) {
 		foreach my $e (&split_quoted_string($_[0]->{'exclude'})) {
 			$cmd .= " --exclude ".quotemeta($e);
@@ -479,6 +491,7 @@ if ($_[0]->{'fs'} eq "tar") {
 	$vcmd = "tar -t -v";
 	$vcmd .= " -z" if ($_[0]->{'gzip'} == 1);
 	$vcmd .= " --bzip" if ($_[0]->{'gzip'} == 2);
+	$vcmd .= " -J" if ($_[0]->{'gzip'} == 3);
 	$vcmd .= " -M" if ($_[0]->{'multi'});
 	}
 elsif ($_[0]->{'fs'} eq "xfs") {
@@ -538,9 +551,9 @@ print &ui_table_row(&hlink($text{'restore_src'}, "rsrc"),
 	       &ui_textbox("file", $_[1]->{'file'}, 50).
 	       " ".&file_chooser_button("file")."<br>" ],
 	  [ 1, &text('dump_host',
-		     &ui_textbox("host", $_[1]->{'host'}, 15),
-		     &ui_textbox("huser", $_[1]->{'huser'}, 8),
-		     &ui_textbox("hfile", $_[1]->{'hfile'}, 20)) ] ]), 3, $tds);
+		     &ui_textbox("host", $_[1]->{'host'}, 20),
+		     &ui_textbox("huser", $_[1]->{'huser'}, 15),
+		     &ui_textbox("hfile", $_[1]->{'hfile'}, 40)) ] ]), 3, $tds);
 
 if ($_[0] eq 'tar') {
 	# tar restore options
@@ -549,7 +562,7 @@ if ($_[0] eq 'tar') {
 		      3, $tds);
 
 	# Password option for SSH
-	print &ui_table_row(&hlink($text{'dump_pass2'},"passs"),
+	print &ui_table_row(&hlink($text{'dump_pass2'},"pass2"),
 		      &ui_password("pass", $_[1]->{'pass'}, 20),
 		      3, $tds);
 
@@ -572,7 +585,8 @@ if ($_[0] eq 'tar') {
 		      &ui_select("gzip", $_[1]->{'gzip'},
 				[ [ 0, $text{'no'} ],
 				  [ 1, $text{'dump_gzip1'} ],
-				  [ 2, $text{'dump_gzip2'} ] ]), 1, $tds);
+				  [ 2, $text{'dump_gzip2'} ],
+				  [ 3, $text{'dump_gzip3'} ] ]), 1, $tds);
 
 	print &ui_table_row(&hlink($text{'restore_keep'},"keep"),
 		      &ui_yesno_radio("keep", 0), 1, $tds);
@@ -580,6 +594,11 @@ if ($_[0] eq 'tar') {
 	# Multiple files
 	print &ui_table_row(&hlink($text{'restore_multi'},"rmulti"),
 		      &ui_yesno_radio("multi", 0), 1, $tds);
+
+	# rmt path option
+	print &ui_table_row(&hlink($text{'dump_rmt'},"rmt"),
+		&ui_opt_textbox("rmt", $_[0]->{'rmt'}, 30, $text{'default'}),
+		3, $tds);
 	}
 elsif ($_[0] eq 'xfs') {
 	# xfs restore options
@@ -612,7 +631,7 @@ else {
 		      3, $tds);
 
 	# Password option for SSH
-	print &ui_table_row(&hlink($text{'dump_pass2'},"passs"),
+	print &ui_table_row(&hlink($text{'dump_pass2'},"pass2"),
 		      &ui_password("pass", $_[1]->{'pass'}, 20),
 		      3, $tds);
 
@@ -681,6 +700,7 @@ if ($_[0] eq 'tar') {
 	$cmd .= " -p" if ($in{'perms'});
 	$cmd .= " -z" if ($in{'gzip'} == 1);
 	$cmd .= " --bzip" if ($in{'gzip'} == 2);
+	$cmd .= " -J" if ($in{'gzip'} == 3);
 	$cmd .= " -k" if ($in{'keep'});
 	if ($in{'multi'}) {
 		!-c $in{'file'} && !-b $in{'file'} ||
@@ -692,6 +712,10 @@ if ($_[0] eq 'tar') {
 	if ($rsh) {
 		$cmd .= " --rsh-command=".quotemeta($rsh);
 		}
+	if (!$in{'rmt_def'}) {
+		$in{'rmt'} =~ /^\S+$/ || &error($text{'dump_ermt'});
+		$cmd .= " --rmt-command=".quotemeta($in{'rmt'});
+		}
 	$cmd .= " $in{'extra'}" if ($in{'extra'});
 	if (!$in{'files_def'}) {
 		$in{'files'} || &error($text{'restore_efiles'});
